Crate pratdiff

Crate pratdiff 

Modules

parse_diff

Structs

ClusterEntry
A mutation that belongs to a cluster.
DiffCluster
A group of mutations that all share the same diff signature.
DiffSignature
A content-based signature for a single mutation.
Printer
Styles
Defaults to using the terminal default colors.

Enums

DiffItem
FilePairEvent
An event produced by walking a pair of paths.
IgnoreWhitespace

Functions

cluster_files
diff
diff_files
rediff
Re-render a piped diff with token-level colorization.
rediff_cluster
Cluster mutations extracted from a parsed diff by change signature.
tokenize_lines
walk_file_pairs
Walk lhs and rhs (files or directory trees) and yield an event for each differing file pair encountered.