Modules
Structs
- Cluster
Entry - A mutation that belongs to a cluster.
- Diff
Cluster - A group of mutations that all share the same diff signature.
- Diff
Signature - A content-based signature for a single mutation.
- Printer
- Styles
- Defaults to using the terminal default colors.
Enums
- Diff
Item - File
Pair Event - An event produced by walking a pair of paths.
- Ignore
Whitespace
Functions
- cluster_
files - diff
- diff_
files - rediff
- Re-render a piped diff with token-level colorization.
- rediff_
cluster - Cluster mutations extracted from a parsed diff by change signature.
- tokenize_
lines - walk_
file_ pairs - Walk lhs and rhs (files or directory trees) and yield an event for each differing file pair encountered.